<?php

namespace Litecms\Product\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Product\Http\Requests\ProductSubcategoryRequest;
use Litecms\Product\Interfaces\ProductSubcategoryRepositoryInterface;
use Litecms\Product\Models\ProductSubcategory;

/**
 * Resource controller class for product_subcategory.
 */
class ProductSubcategoryResourceController extends BaseController
{

    /**
     * Initialize product_subcategory resource controller.
     *
     * @param type ProductSubcategoryRepositoryInterface $product_subcategory
     *
     * @return null
     */
    public function __construct(ProductSubcategoryRepositoryInterface $product_subcategory)
    {
        parent::__construct();
        $this->repository = $product_subcategory;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Product\Repositories\Criteria\ProductSubcategoryResourceCriteria::class);
    }

    /**
     * Display a list of product_subcategory.
     *
     * @return Response
     */
    public function index(ProductSubcategoryRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Product\Repositories\Presenter\ProductSubcategoryPresenter::class)
                ->$function();
        }

        $product_subcategories = $this->repository->paginate();

        return $this->response->title(trans('product::product_subcategory.names'))
            ->view('product::product_subcategory.index', true)
            ->data(compact('product_subcategories'))
            ->output();
    }

    /**
     * Display product_subcategory.
     *
     * @param Request $request
     * @param Model   $product_subcategory
     *
     * @return Response
     */
    public function show(ProductSubcategoryRequest $request, ProductSubcategory $product_subcategory)
    {

        if ($product_subcategory->exists) {
            $view = 'product::product_subcategory.show';
        } else {
            $view = 'product::product_subcategory.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('product::product_subcategory.name'))
            ->data(compact('product_subcategory'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new product_subcategory.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ProductSubcategoryRequest $request)
    {

        $product_subcategory = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('product::product_subcategory.name')) 
            ->view('product::product_subcategory.create', true) 
            ->data(compact('product_subcategory'))
            ->output();
    }

    /**
     * Create new product_subcategory.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProductSubcategoryRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $product_subcategory                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('product::product_subcategory.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('product/product_subcategory/' . $product_subcategory->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/product/product_subcategory'))
                ->redirect();
        }

    }

    /**
     * Show product_subcategory for editing.
     *
     * @param Request $request
     * @param Model   $product_subcategory
     *
     * @return Response
     */
    public function edit(ProductSubcategoryRequest $request, ProductSubcategory $product_subcategory)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('product::product_subcategory.name'))
            ->view('product::product_subcategory.edit', true)
            ->data(compact('product_subcategory'))
            ->output();
    }

    /**
     * Update the product_subcategory.
     *
     * @param Request $request
     * @param Model   $product_subcategory
     *
     * @return Response
     */
    public function update(ProductSubcategoryRequest $request, ProductSubcategory $product_subcategory)
    {
        try {
            $attributes = $request->all();

            $product_subcategory->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('product::product_subcategory.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('product/product_subcategory/' . $product_subcategory->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/product_subcategory/' . $product_subcategory->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the product_subcategory.
     *
     * @param Model   $product_subcategory
     *
     * @return Response
     */
    public function destroy(ProductSubcategoryRequest $request, ProductSubcategory $product_subcategory)
    {
        try {

            $product_subcategory->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('product::product_subcategory.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('product/product_subcategory/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/product_subcategory/' . $product_subcategory->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple product_subcategory.
     *
     * @param Model   $product_subcategory
     *
     * @return Response
     */
    public function delete(ProductSubcategoryRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('product::product_subcategory.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('product/product_subcategory'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/product/product_subcategory'))
                ->redirect();
        }

    }

    /**
     * Restore deleted product_subcategories.
     *
     * @param Model   $product_subcategory
     *
     * @return Response
     */
    public function restore(ProductSubcategoryRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('product::product_subcategory.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/product/product_subcategory'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/product/product_subcategory/'))
                ->redirect();
        }

    }

}
